## SAP Data Services Web Service Client 

This library can simplify your operations on SAP DS server with utilizing its web service via SOAP requests:
* retrieve a list of available repositories;
* validate repository objects;
* run or stop batch jobs;
* retrieve a list of batch jobs in the repository;
* retrieve a list of jobs or job executions for a selected repository and job - all or within the specified period of time ;
* retrieve error, monitor or trace logs for a batch job;
* retrieve a list of scheduled tasks for the selected repository;
* retrieve a list or status of job servers for a repository;
* retrieve a list of system configurations, substitution parameters, and batch job global variables;
* etc.

For use cases, explore [test_client](https://github.com/sparklingSky/sap-ds-web-service-client/blob/main/test_client.py)

## ⚖️ License
This library is distributed under a **Custom Dual License**.
It permits **free use for non-commercial or internal business purposes only**.

**Commercial distribution** requires a separate commercial license. Please see the full terms in the [LICENSE.md](https://github.com/sparklingSky/sap-ds-web-service-client/blob/main/LICENSE.md) file.